==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/opensearch/kotlin/inputs/DomainAdvancedSecurityOptionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.opensearch.kotlin.inputs

import com.pulumi.aws.opensearch.inputs.DomainAdvancedSecurityOptionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property anonymousAuthEnabled Whether Anonymous auth is enabled. Enables fine-grained access control on an existing domain. Ignored unless `advanced_security_options` are enabled. _Can only be enabled on an existing domain._
 * @property enabled Whether advanced security is enabled.
 * @property internalUserDatabaseEnabled Whether the internal user database is enabled. Default is `false`.
 * @property masterUserOptions Configuration block for the main user. Detailed below.
 */
public data class DomainAdvancedSecurityOptionsArgs(
    public val anonymousAuthEnabled: Output<Boolean>? = null,
    public val enabled: Output<Boolean>,
    public val internalUserDatabaseEnabled: Output<Boolean>? = null,
    public val masterUserOptions: Output<DomainAdvancedSecurityOptionsMasterUserOptionsArgs>? = null,
) : ConvertibleToJava<com.pulumi.aws.opensearch.inputs.DomainAdvancedSecurityOptionsArgs> {
    override fun toJava(): com.pulumi.aws.opensearch.inputs.DomainAdvancedSecurityOptionsArgs =
        com.pulumi.aws.opensearch.inputs.DomainAdvancedSecurityOptionsArgs.builder()
            .anonymousAuthEnabled(anonymousAuthEnabled?.applyValue({ args0 -> args0 }))
            .enabled(enabled.applyValue({ args0 -> args0 }))
            .internalUserDatabaseEnabled(internalUserDatabaseEnabled?.applyValue({ args0 -> args0 }))
            .masterUserOptions(
                masterUserOptions?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [DomainAdvancedSecurityOptionsArgs].
 */
@PulumiTagMarker
public class DomainAdvancedSecurityOptionsArgsBuilder internal constructor() {
    private var anonymousAuthEnabled: Output<Boolean>? = null

    private var enabled: Output<Boolean>? = null

    private var internalUserDatabaseEnabled: Output<Boolean>? = null

    private var masterUserOptions: Output<DomainAdvancedSecurityOptionsMasterUserOptionsArgs>? = null

    /**
     * @param value Whether Anonymous auth is enabled. Enables fine-grained access control on an existing domain. Ignored unless `advanced_security_options` are enabled. _Can only be enabled on an existing domain._
     */
    @JvmName("hpbejplktsdfbrcw")
    public suspend fun anonymousAuthEnabled(`value`: Output<Boolean>) {
        this.anonymousAuthEnabled = value
    }

    /**
     * @param value Whether advanced security is enabled.
     */
    @JvmName("tuqtwxaxcswnonfp")
    public suspend fun enabled(`value`: Output<Boolean>) {
        this.enabled = value
    }

    /**
     * @param value Whether the internal user database is enabled. Default is `false`.
     */
    @JvmName("akyhewgoxcaghren")
    public suspend fun internalUserDatabaseEnabled(`value`: Output<Boolean>) {
        this.internalUserDatabaseEnabled = value
    }

    /**
     * @param value Configuration block for the main user. Detailed below.
     */
    @JvmName("qfjpdijskytwucmv")
    public suspend
    fun masterUserOptions(`value`: Output<DomainAdvancedSecurityOptionsMasterUserOptionsArgs>) {
        this.masterUserOptions = value
    }

    /**
     * @param value Whether Anonymous auth is enabled. Enables fine-grained access control on an existing domain. Ignored unless `advanced_security_options` are enabled. _Can only be enabled on an existing domain._
     */
    @JvmName("jcmmbbttvbkwvbup")
    public suspend fun anonymousAuthEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.anonymousAuthEnabled = mapped
    }

    /**
     * @param value Whether advanced security is enabled.
     */
    @JvmName("fnsmuhlitciktyfo")
    public suspend fun enabled(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value Whether the internal user database is enabled. Default is `false`.
     */
    @JvmName("qagwuvomnjfnsarr")
    public suspend fun internalUserDatabaseEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.internalUserDatabaseEnabled = mapped
    }

    /**
     * @param value Configuration block for the main user. Detailed below.
     */
    @JvmName("ttpurpkjaohmyhqy")
    public suspend
    fun masterUserOptions(`value`: DomainAdvancedSecurityOptionsMasterUserOptionsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.masterUserOptions = mapped
    }

    /**
     * @param argument Configuration block for the main user. Detailed below.
     */
    @JvmName("jdskjehpxsvuexcm")
    public suspend
    fun masterUserOptions(argument: suspend DomainAdvancedSecurityOptionsMasterUserOptionsArgsBuilder.() -> Unit) {
        val toBeMapped = DomainAdvancedSecurityOptionsMasterUserOptionsArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.masterUserOptions = mapped
    }

    internal fun build(): DomainAdvancedSecurityOptionsArgs = DomainAdvancedSecurityOptionsArgs(
        anonymousAuthEnabled = anonymousAuthEnabled,
        enabled = enabled ?: throw PulumiNullFieldException("enabled"),
        internalUserDatabaseEnabled = internalUserDatabaseEnabled,
        masterUserOptions = masterUserOptions,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/opensearch/kotlin/inputs/DomainAdvancedSecurityOptionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.opensearch.kotlin.inputs

import com.pulumi.aws.opensearch.inputs.DomainAdvancedSecurityOptionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property anonymousAuthEnabled Whether Anonymous auth is enabled. Enables fine-grained access control on an existing domain. Ignored unless `advanced_security_options` are enabled. _Can only be enabled on an existing domain._
 * @property enabled Whether advanced security is enabled.
 * @property internalUserDatabaseEnabled Whether the internal user database is enabled. Default is `false`.
 * @property masterUserOptions Configuration block for the main user. Detailed below.
 */
public data class DomainAdvancedSecurityOptionsArgs(
    public val anonymousAuthEnabled: Output<Boolean>? = null,
    public val enabled: Output<Boolean>,
    public val internalUserDatabaseEnabled: Output<Boolean>? = null,
    public val masterUserOptions: Output<DomainAdvancedSecurityOptionsMasterUserOptionsArgs>? = null,
) : ConvertibleToJava<com.pulumi.aws.opensearch.inputs.DomainAdvancedSecurityOptionsArgs> {
    override fun toJava(): com.pulumi.aws.opensearch.inputs.DomainAdvancedSecurityOptionsArgs =
        com.pulumi.aws.opensearch.inputs.DomainAdvancedSecurityOptionsArgs.builder()
            .anonymousAuthEnabled(anonymousAuthEnabled?.applyValue({ args0 -> args0 }))
            .enabled(enabled.applyValue({ args0 -> args0 }))
            .internalUserDatabaseEnabled(internalUserDatabaseEnabled?.applyValue({ args0 -> args0 }))
            .masterUserOptions(
                masterUserOptions?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [DomainAdvancedSecurityOptionsArgs].
 */
@PulumiTagMarker
public class DomainAdvancedSecurityOptionsArgsBuilder internal constructor() {
    private var anonymousAuthEnabled: Output<Boolean>? = null

    private var enabled: Output<Boolean>? = null

    private var internalUserDatabaseEnabled: Output<Boolean>? = null

    private var masterUserOptions: Output<DomainAdvancedSecurityOptionsMasterUserOptionsArgs>? = null

    /**
     * @param value Whether Anonymous auth is enabled. Enables fine-grained access control on an existing domain. Ignored unless `advanced_security_options` are enabled. _Can only be enabled on an existing domain._
     */
    @JvmName("eouwhxypnreawghe")
    public suspend fun anonymousAuthEnabled(`value`: Output<Boolean>) {
        this.anonymousAuthEnabled = value
    }

    /**
     * @param value Whether advanced security is enabled.
     */
    @JvmName("wgbagxfodbpgpsst")
    public suspend fun enabled(`value`: Output<Boolean>) {
        this.enabled = value
    }

    /**
     * @param value Whether the internal user database is enabled. Default is `false`.
     */
    @JvmName("omfkvuqykdayxdgq")
    public suspend fun internalUserDatabaseEnabled(`value`: Output<Boolean>) {
        this.internalUserDatabaseEnabled = value
    }

    /**
     * @param value Configuration block for the main user. Detailed below.
     */
    @JvmName("npvkwkutihrxsuue")
    public suspend fun masterUserOptions(`value`: Output<DomainAdvancedSecurityOptionsMasterUserOptionsArgs>) {
        this.masterUserOptions = value
    }

    /**
     * @param value Whether Anonymous auth is enabled. Enables fine-grained access control on an existing domain. Ignored unless `advanced_security_options` are enabled. _Can only be enabled on an existing domain._
     */
    @JvmName("uxguyagphvgoejfd")
    public suspend fun anonymousAuthEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.anonymousAuthEnabled = mapped
    }

    /**
     * @param value Whether advanced security is enabled.
     */
    @JvmName("jxiuxmytdgogebrw")
    public suspend fun enabled(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value Whether the internal user database is enabled. Default is `false`.
     */
    @JvmName("qbdgxmeenkdlssqf")
    public suspend fun internalUserDatabaseEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.internalUserDatabaseEnabled = mapped
    }

    /**
     * @param value Configuration block for the main user. Detailed below.
     */
    @JvmName("graolekgmaviphbu")
    public suspend fun masterUserOptions(`value`: DomainAdvancedSecurityOptionsMasterUserOptionsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.masterUserOptions = mapped
    }

    /**
     * @param argument Configuration block for the main user. Detailed below.
     */
    @JvmName("rjxqsnskqruhkvtv")
    public suspend fun masterUserOptions(argument: suspend DomainAdvancedSecurityOptionsMasterUserOptionsArgsBuilder.() -> Unit) {
        val toBeMapped = DomainAdvancedSecurityOptionsMasterUserOptionsArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.masterUserOptions = mapped
    }

    internal fun build(): DomainAdvancedSecurityOptionsArgs = DomainAdvancedSecurityOptionsArgs(
        anonymousAuthEnabled = anonymousAuthEnabled,
        enabled = enabled ?: throw PulumiNullFieldException("enabled"),
        internalUserDatabaseEnabled = internalUserDatabaseEnabled,
        masterUserOptions = masterUserOptions,
    )
}
